==> haskell-breakpoint-0.1.4.0-14.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.4.0
visibility:           public
id:                   breakpoint-0.1.4.0-7NRPu2ELfAS2UCOOxHPg7z
key:                  breakpoint-0.1.4.0-7NRPu2ELfAS2UCOOxHPg7z
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

category:             Development
abi:                  8d12efbe4afa5ca6b97b8dadbefd625b
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:
    Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
    Debug.Breakpoint.TimerManager.Names

import-dirs:          /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.4.0-7NRPu2ELfAS2UCOOxHPg7z
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-9.6.6 haskeline-0.8.2.1
    mtl-2.3.1 pretty-simple-4.1.3.0-FVwSxUgLrGFBqfQuiA3nvl
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-breakpoint-0.1.4.0-16-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.4.0
visibility:           public
id:                   breakpoint-0.1.4.0-DxoadWPZNDq1AoNzsfzvgg
key:                  breakpoint-0.1.4.0-DxoadWPZNDq1AoNzsfzvgg
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

category:             Development
abi:                  96080b3e0ba97d21d7475939c673aee5
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:
    Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
    Debug.Breakpoint.TimerManager.Names

import-dirs:          /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.4.0-DxoadWPZNDq1AoNzsfzvgg
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh base-4.18.2.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-9.6.6 haskeline-0.8.2.1
    mtl-2.3.1 pretty-simple-4.1.4.0-L06q4MjGm0c3vpgIEWeUpU
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
